module HROOT.Graf.TPad
       (TPad(..), ITPad(..), upcastTPad, downcastTPad, newTPad) where
import HROOT.Graf.TPad.RawType
import HROOT.Graf.TPad.Interface
import HROOT.Graf.TPad.Implementation
